Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3415)

Unified Diff: chrome/browser/extensions/image_loading_tracker.h

Issue 256022: Loads local resources from current locale subtree if available, if not it fal... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/image_loading_tracker.h
===================================================================
--- chrome/browser/extensions/image_loading_tracker.h (revision 28157)
+++ chrome/browser/extensions/image_loading_tracker.h (working copy)
@@ -2,18 +2,20 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_IMAGE_LOADING_TRACKER_H_
-#define CHROME_BROWSER_IMAGE_LOADING_TRACKER_H_
+#ifndef CHROME_BROWSER_EXTENSIONS_IMAGE_LOADING_TRACKER_H_
+#define CHROME_BROWSER_EXTENSIONS_IMAGE_LOADING_TRACKER_H_
#include "base/ref_counted.h"
-class FilePath;
+class ExtensionResource;
class SkBitmap;
// The views need to load their icons asynchronously but might be deleted before
// the images have loaded. This class stays alive while the request is in
// progress (manages its own lifetime) and keeps track of whether the view still
// cares about the icon loading.
+// Consider abstracting out a FilePathProvider (ExtensionResource) and moving
+// back to chrome/browser/ if other subsystems want to use it.
class ImageLoadingTracker
: public base::RefCountedThreadSafe<ImageLoadingTracker> {
public:
@@ -40,10 +42,10 @@
observer_ = NULL;
}
// Specify path of image to load. This method must be called a number of
// times equal to the |image_count| arugment to the constructor. Calling it
// any more or less than that is an error.
- void PostLoadImageTask(FilePath path);
+ void PostLoadImageTask(const ExtensionResource& resource);
private:
class LoadImageTask;
@@ -69,4 +71,4 @@
DISALLOW_COPY_AND_ASSIGN(ImageLoadingTracker);
};
-#endif // CHROME_BROWSER_IMAGE_LOADING_TRACKER_H_
+#endif // CHROME_BROWSER_EXTENSIONS_IMAGE_LOADING_TRACKER_H_
« no previous file with comments | « chrome/browser/extensions/file_reader_unittest.cc ('k') | chrome/browser/extensions/image_loading_tracker.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -40,10 +42,10 @@
observer_ = NULL;
}
- // Specify path of image to load. This method must be called a number of
+ // Specify image resource to load. This method must be called a number of
// times equal to the |image_count| arugment to the constructor. Calling it
// any more or less than that is an error.
This is Rietveld 408576698